@@ -221,7 +221,7 @@ get_config_client ()
 	 *	  wait until the operation finishes
 	 */
 	if (config_client == NULL){
-		gsize  len;
+		gint len;
 		gchar *full_file;
 		gchar *user_config;
 
@@ -1136,7 +1136,7 @@ gda_config_free_provider_list (GList *list)
  * gda_config_get_provider_by_name
  * @name: name of the provider to search for.
  *
- * Gets a #GdaProviderInfo structure from the provider list given its name.
+ * Gets a #GdaProviderInfo structure from the provider list givin its name.
  *
  * Returns: a #GdaProviderInfo structure, if found, or %NULL if not found.
  */
@@ -1164,6 +1164,50 @@ gda_config_get_provider_by_name (const gchar *name)
 	return NULL;
 }
 
+/**
+ * gda_config_get_provider_model
+ *
+ * Fills and returns a new #GdaDataModel object using information from all 
+ * providers which are currently installed in the system.
+ *
+ * Rows are separated in 3 columns: 
+ * 'Id', 'Location' and 'Description'. 
+ *
+ * Returns: a new #GdaDataModel object. 
+ */
+GdaDataModel *
+gda_config_get_provider_model (void)
+{
+	GList *prov_list;
+	GList *l;
+	GdaDataModel *model;
+
+	model = gda_data_model_array_new (3);
+	gda_data_model_set_column_title (model, 0, _("Id"));
+	gda_data_model_set_column_title (model, 1, _("Location"));
+	gda_data_model_set_column_title (model, 2, _("Description"));
+
+	/* convert the returned GList into a GdaDataModelArray */
+	prov_list = gda_config_get_provider_list ();
+	for (l = prov_list; l != NULL; l = l->next) {
+		GList *value_list = NULL;
+		GdaProviderInfo *prov_info = (GdaProviderInfo *) l->data;
+
+		g_assert (prov_info != NULL);
+
+		value_list = g_list_append (value_list, gda_value_new_string (prov_info->id));
+		value_list = g_list_append (value_list, gda_value_new_string (prov_info->location));
+		value_list = g_list_append (value_list, gda_value_new_string (prov_info->description));
+
+		gda_data_model_append_row (GDA_DATA_MODEL (model), value_list);
+	}
+	
+	/* free memory */
+	gda_config_free_provider_list (prov_list);
+	
+	return model;
+}
+
 /**
  * gda_provider_info_copy
  * @src: provider information to get a copy from.
@@ -1224,7 +1268,7 @@ gda_config_free_provider_info (GdaProviderInfo *provider_info)
  *
  * Returns a list of all data sources currently configured in the system.
  * Each of the nodes in the returned GList is a #GdaDataSourceInfo.
- * To free the returned list, call the #gda_config_free_data_source_list
+ * To free the returned list, call the #gda_config_free_data_source_info
  * function.
  *
  * Returns: a GList of #GdaDataSourceInfo structures.
@@ -1281,7 +1325,7 @@ gda_config_get_data_source_list (void)
  * gda_config_find_data_source
  * @name: name of the data source to search for.
  *
- * Gets a #GdaDataSourceInfo structure from the data source list given its 
+ * Gets a #GdaDataSourceInfo structure from the data source list givin its 
  * name.
  *
  * Returns: a #GdaDataSourceInfo structure, if found, or %NULL if not found.
@@ -1608,7 +1652,7 @@ gda_config_add_listener (const gchar *path,
  * @id: the ID of the listener to remove.
  *
  * Removes a configuration listener previously installed with
- * #gda_config_add_listener, given its ID.
+ * #gda_config_add_listener, givin its ID.
  */
 void
 gda_config_remove_listener (guint id)
