@@ -118,10 +118,11 @@ gda_data_model_array_append_row (GdaDataModel *model, const GList *values)
 	if (len != GDA_DATA_MODEL_ARRAY (model)->priv->number_of_columns)
 		return NULL;
 
-	row = gda_row_new_from_list (values);
+	row = gda_row_new_from_list (model, values);
 	if (row) {
 		g_ptr_array_add (GDA_DATA_MODEL_ARRAY (model)->priv->rows, row);
-		gda_data_model_changed (model);
+		gda_row_set_number (row, GDA_DATA_MODEL_ARRAY (model)->priv->rows->len - 1);
+		gda_data_model_row_inserted (model, GDA_DATA_MODEL_ARRAY (model)->priv->rows->len - 1);
 	}
 
 	return (const GdaRow *) row;
@@ -134,7 +135,7 @@ gda_data_model_array_remove_row (GdaDataModel *model, const GdaRow *row)
 	g_return_val_if_fail (row != NULL, FALSE);
 
 	if (g_ptr_array_remove (GDA_DATA_MODEL_ARRAY (model)->priv->rows, (gpointer) row)) {
-		gda_data_model_changed (model);
+		gda_data_model_row_removed (model, gda_row_get_number (row));
 		return TRUE;
 	}
 
@@ -216,6 +217,9 @@ gda_data_model_array_get_type (void)
 
 /**
  * gda_data_model_array_new
+ * @cols: number of columns for rows in this data model.
+ *
+ * Returns: a pointer to the newly created #GdaDataModel.
  */
 GdaDataModel *
 gda_data_model_array_new (gint cols)
@@ -229,6 +233,11 @@ gda_data_model_array_new (gint cols)
 
 /**
  * gda_data_model_array_set_n_columns
+ * @model: the #GdaDataModelArray.
+ * @cols: number of columns for rows this data model should use.
+ *
+ * Sets the number of columns for rows inserted in this model. 
+ * @cols must be greated than or equal to 0.
  */
 void
 gda_data_model_array_set_n_columns (GdaDataModelArray *model, gint cols)
@@ -240,6 +249,9 @@ gda_data_model_array_set_n_columns (GdaDataModelArray *model, gint cols)
 
 /**
  * gda_data_model_array_clear
+ * @model: the model to clear.
+ *
+ * Frees all the rows inserted in @model.
  */
 void
 gda_data_model_array_clear (GdaDataModelArray *model)
