@@ -43,14 +43,20 @@ typedef struct {
 	gboolean auto_increment;
 	glong auto_increment_start;
 	glong auto_increment_step;
+	gint position;
+	GdaValue *default_value;
 } GdaFieldAttributes;
 
+/* NOTE: Can't find any code using GdaField struct */
 typedef struct {
 	gint actual_size;
 	GdaValue *value;
 	GdaFieldAttributes *attributes;
 } GdaField;
 
+#define GDA_TYPE_FIELD_ATTRIBUTES (gda_field_attributes_get_type ())
+
+GType               gda_field_attributes_get_type (void);
 GdaFieldAttributes *gda_field_attributes_new (void);
 GdaFieldAttributes *gda_field_attributes_copy (GdaFieldAttributes *fa);
 void                gda_field_attributes_free (GdaFieldAttributes *fa);
@@ -78,6 +84,11 @@ void                gda_field_attributes_set_references (GdaFieldAttributes *fa,
 gboolean            gda_field_attributes_get_auto_increment (GdaFieldAttributes *fa);
 void                gda_field_attributes_set_auto_increment (GdaFieldAttributes *fa,
 							     gboolean is_auto);
+gint                gda_field_attributes_get_position (GdaFieldAttributes *fa);
+void                gda_field_attributes_set_position (GdaFieldAttributes *fa, gint position);
+
+const GdaValue     *gda_field_attributes_get_default_value (GdaFieldAttributes *fa);
+void                gda_field_attributes_set_default_value (GdaFieldAttributes *fa, const GdaValue *default_value);
 
 G_END_DECLS
 
