@@ -143,7 +143,6 @@ gda_string_hash_to_list (GHashTable *hash_table)
 gchar *
 gda_sql_replace_placeholders (const gchar *sql, GdaParameterList *params)
 {
-	GString *str;
 	sql_statement *sql_stmt;
 
 	g_return_val_if_fail (sql != NULL, NULL);
@@ -208,7 +207,7 @@ gda_file_save (const gchar *filename, const gchar *buffer, gint len)
 	
 	g_return_val_if_fail (filename != NULL, FALSE);
 
-	fd = open (filename, O_RDWR | O_CREAT | O_TRUNC, 0644);
+	fd = open (filename, O_RDWR | O_CREAT, 0644);
 	if (fd == -1) {
 		gda_log_error (_("Could not create file %s"), filename);
 		return FALSE;
