@@ -45,46 +45,78 @@ gda_mysql_make_error (MYSQL *handle)
 	return error;
 }
 
-GdaType
+GdaValueType
 gda_mysql_type_to_gda (enum enum_field_types mysql_type)
 {
 	switch (mysql_type) {
 	case FIELD_TYPE_DATE :
-		return GDA_TYPE_DATE;
+		return GDA_VALUE_TYPE_DATE;
 	case FIELD_TYPE_DECIMAL :
 	case FIELD_TYPE_DOUBLE :
-		return GDA_TYPE_DOUBLE;
+		return GDA_VALUE_TYPE_DOUBLE;
 	case FIELD_TYPE_FLOAT :
-		return GDA_TYPE_SINGLE;
+		return GDA_VALUE_TYPE_SINGLE;
 	case FIELD_TYPE_LONG :
 	case FIELD_TYPE_YEAR :
-		return GDA_TYPE_INTEGER;
+		return GDA_VALUE_TYPE_INTEGER;
 	case FIELD_TYPE_LONGLONG :
 	case FIELD_TYPE_INT24 :
-		return GDA_TYPE_BIGINT;
+		return GDA_VALUE_TYPE_BIGINT;
 	case FIELD_TYPE_SHORT :
-		return GDA_TYPE_SMALLINT;
+		return GDA_VALUE_TYPE_SMALLINT;
 	case FIELD_TYPE_TIME :
-		return GDA_TYPE_TIME;
+		return GDA_VALUE_TYPE_TIME;
 	case FIELD_TYPE_TIMESTAMP :
 	case FIELD_TYPE_DATETIME :
-		return GDA_TYPE_TIMESTAMP;
+		return GDA_VALUE_TYPE_TIMESTAMP;
 	case FIELD_TYPE_TINY :
-		return GDA_TYPE_TINYINT;
+		return GDA_VALUE_TYPE_TINYINT;
 	case FIELD_TYPE_TINY_BLOB :
 	case FIELD_TYPE_MEDIUM_BLOB :
 	case FIELD_TYPE_LONG_BLOB :
 	case FIELD_TYPE_BLOB :
-		return GDA_TYPE_BINARY;
+		return GDA_VALUE_TYPE_BINARY;
 	case FIELD_TYPE_VAR_STRING :
 	case FIELD_TYPE_STRING :
-		return GDA_TYPE_STRING;
+		/* FIXME: Check for BINARY flags and use blob */
+		return GDA_VALUE_TYPE_STRING;
 	case FIELD_TYPE_NULL :
 	case FIELD_TYPE_NEWDATE :
 	case FIELD_TYPE_ENUM :
 	case FIELD_TYPE_SET :
-		return GDA_TYPE_STRING;
+		return GDA_VALUE_TYPE_STRING;
 	}
 
-	return GDA_TYPE_UNKNOWN;
+	return GDA_VALUE_TYPE_UNKNOWN;
+}
+
+gchar *
+gda_mysql_value_to_sql_string (GdaValue *value)
+{
+	gchar *val_str;
+	gchar *ret;
+
+	g_return_val_if_fail (value != NULL, NULL);
+
+	val_str = gda_value_stringify (value);
+	if (!val_str)
+		return NULL;
+
+	switch (value->type) {
+	case GDA_VALUE_TYPE_BIGINT :
+	case GDA_VALUE_TYPE_DOUBLE :
+	case GDA_VALUE_TYPE_INTEGER :
+	case GDA_VALUE_TYPE_NUMERIC :
+	case GDA_VALUE_TYPE_SINGLE :
+	case GDA_VALUE_TYPE_SMALLINT :
+	case GDA_VALUE_TYPE_TINYINT :
+		ret = g_strdup (val_str);
+		break;
+	default :
+		ret = g_strdup_printf ("\"%s\"", val_str);
+	}
+
+	g_free (val_str);
+
+	return ret;
 }
